package MT::Plugin::DirectoryUtility;

use strict;
use warnings;

use MT::Entry;
use MT::Category;
use MT::Template::Context;
use Data::Dumper;

use vars qw( $NAME $VERSION );
$NAME = 'DirectoryUtility';
$VERSION = '1.0';

use base qw( MT::Plugin );
my $plugin = MT::Plugin::DirectoryUtility->new({
        name => $NAME,
        version => $VERSION,
        author_name => 'SKYARC System Co.,Ltd.',
        author_link => 'http://www.skyarc.co.jp',
#        description => "<MT_TRANS phrase='Tags'>:  <\$TopLevelDirectoryBasename\$>, <\$TopLevelDirectoryName\$>, <\$DirectoryDepth\$>",
});
MT->add_plugin ($plugin);

MT::Template::Context->add_tag(TopLevelDirectoryBasename => \&_topLevel_directory_basename);
MT::Template::Context->add_tag(TopLevelDirectoryName => \&_topLevel_directory_name);
MT::Template::Context->add_tag(TopLevelDirectoryId => \&_topLevel_directory_id);
MT::Template::Context->add_tag(DirectoryDepth => \&_directory_depth);

sub _topLevel_directory_basename {
    my ($ctx, $args) = @_;

    my $category = $ctx->stash ('category');

    unless ($category) {
        my $entry = $ctx->stash ('entry');
        if ($entry){
            $category = $entry->category;
        }
    }

    unless ($category) {
        $category = $ctx->stash ('archive_category');
    }

    unless ($category) {
        return "";
    }

    my @parent_categories = $category->parent_categories;

    foreach my $cate (@parent_categories) {
        unless ($cate->parent_categories){
            $category = $cate;
        }
    }
    return $category->basename;
}

sub _topLevel_directory_name {
    my ($ctx, $args) = @_;

    my $category = $ctx->stash ('category');

    unless ($category) {
        my $entry = $ctx->stash ('entry');
        if ($entry){
            $category = $entry->category;
        }
    }

    unless ($category) {
        $category = $ctx->stash ('archive_category');
    }

    unless ($category) {
        return "";
    }

    my @parent_categories = $category->parent_categories;

    foreach my $cate (@parent_categories) {
        unless ($cate->parent_categories){
            $category = $cate;
        }
    }
    return $category->label;
}

sub _topLevel_directory_id {
    my ($ctx, $args) = @_;

    my $category = $ctx->stash ('category');

    unless ($category) {
        my $entry = $ctx->stash ('entry');
        if ($entry){
            $category = $entry->category;
        }
    }

    unless ($category) {
        $category = $ctx->stash ('archive_category');
    }

    unless ($category) {
        return "";
    }

    my @parent_categories = $category->parent_categories;

    foreach my $cate (@parent_categories) {
        unless ($cate->parent_categories){
            $category = $cate;
        }
    }
    return $category->id;
}

sub _directory_depth {
    my ($ctx, $args) = @_;

    my $category = $ctx->stash ('category');

    unless ($category) {
        my $entry = $ctx->stash ('entry');
        if ($entry){
            $category = $entry->category;
        }
    }

    unless ($category) {
        $category = $ctx->stash ('archive_category');
    }

    unless ($category) {
        return "";
    }

    my @parent_categories = $category->parent_categories;

    return (scalar @parent_categories) + 1;
}
